
#------------------------------------------------------------------------------
# Keszitette: Szintai Balazs, IV. eves meteorologus hallgato
#------------------------------------------------------------------------------


set -e
#
MAINDIR=/home/szintaib/gribex/
WORKDIR=${MAINDIR}/work
GRIBDIR=${MAINDIR}/grib
BINARYDATA_DIR=${MAINDIR}/binary
LIBRARY_DIR=${MAINDIR}/library
#
cd $WORKDIR
#

# A kulso parameter(input file nev) feldolgozas
#---------------------------------------------------

umask 077 

if [ "$#" = 1 ]
then
    gribfile=${GRIBDIR}/$1.grib 
    if [ ! -f $gribfile ]
    then
	echo "HIBA: nem letezik a megadott input GRIB file" ${gribfile} 
	exit 1
    else 
        ls -l $gribfile  	
        rm -f input_gribfile 
        ln -sf  $gribfile input_gribfile
 
        binfile=${BINARYDATA_DIR}/$1.bin
        hdrfile=${WORKDIR}/$1.hdr
        rm -f $binfile $asciifile $hdrfile 
    fi
else
    echo " HIBA: nincs input file megadva "
    echo " .grb kiterjesztes nelkul kell a GRIB file nevet megadnunk " 
    echo " grib2bin.sh input_filenev  > grib header jellemzok ] "
    exit 1
fi

#
cd $WORKDIR
PATH=$PATH:.              
export PATH 
CURRENT_DIR=`pwd` ; export CURRENT_DIR

# a dekodolo program fortranban irt foprogramja  
     
cat>grdemo.f<<EOF
      PROGRAM GRDEMO
C
C**** GRDEMO - Program to demonstrate use of GRIBEX routine.
C
C     Purpose.
C     --------
C
C     Demonstrates use of GRIBEX routine to unpack
C     GRIB coded data.
C
C**   Interface.
C     ----------
C
C     File of GRIB coded data attached as 'input_gribfile'
C
C     Method.
C     -------
C
C     Prints sections 0, 1, 2, 3 and 4 of GRIB message.
C
C     Reads packed fields. THIS READ IS FOR UNBLOCKED FILES ONLY.
C
C     If you retrieved the data with MARS on the workstations,
C     the files are unblocked.
C     If you retrieved the data on UNICOS, the file has to be unblocked.
C     Use the unblock command on the workstations or uscpblock on UNICOS
C     first to unblock this file.
C
C     Externals.
C     ----------
C
C     GRIBEX
C     GRPRS0
C     GRPRS1
C     GRPRS2
C     GRPRS3
C     GRPRS4
C
C     Reference.
C     ----------
C
C     WMO Manual on Codes for GRIB definition.
C     WMO Publication No. 9, Volume B, for grid catalogue numbers.
C
C     Comments.
C     ---------
C
C     GRIBEX provides a number of packing/unpacking options.
C     See documentation in routine GRIBEX for details.
C
C     Author.
C     -------
C
C     J. Hennessy     ECMWF   25.06.91
C
C     Modifications.
C     --------------
C
C     D. Lucas		ECMWF   05.93      
C			adapted for the workstations.
C
C     -----------------------------------------------------------------
      IMPLICIT NONE
C
C     SIZE OF DOMAIN / I. IHASZ 22/10/2003  
C
        INTEGER NXMAX,NYMAX
        PARAMETER (NXMAX=9,NYMAX=9)
C
C
C     Arrays are dimensioned to accommodate T213/N160 data volumes.
      INTEGER JPACK
      PARAMETER ( JPACK = 70000 )
C
C     This parameter holds the 'number of bytes per word'
      INTEGER JPNBYTE
      PARAMETER ( JPNBYTE = 4 )
C
      REAL ZSEC2, ZSEC3, ZSEC4
      INTEGER ISEC0, ISEC1, ISEC2, ISEC3, ISEC4
      INTEGER NMESSAGE, NUMERR, ISTATUS, ILENB, IPUNP
      INTEGER KUNIT, LENGTH, IWORD
      INTEGER loop,ios,krec
C
      INTEGER ISEC 
      DIMENSION ISEC(1540)
      INTEGER K
C
C     Array for integer parameters from section 0 of GRIB message.
      DIMENSION ISEC0(2)
C
C     Array for integer parameters from section 1 of GRIB message.
      DIMENSION ISEC1(512)
C
C     Array for integer parameters from section 2 of GRIB message.
      DIMENSION ISEC2(512)
C
C     Array for integer parameters from section 3 of GRIB message.
      DIMENSION ISEC3(2)
C
C     Array for integer parameters from section 4 of GRIB message.
      DIMENSION ISEC4(512)
C
C     Array for real parameters from section 2 of GRIB message.
      DIMENSION ZSEC2(512)
C
C     Array for real parameters from section 3 of GRIB message.
      DIMENSION ZSEC3(2)
C
C     Array for real parameters from section 4 of GRIB message.
C     This is the binary data section and the array to hold
C     the unpacked data may need to be 4 times as long as that
C     for the packed data (or more!).
C
      DIMENSION ZSEC4(JPACK*4)
C
C     Array to read in packed data.
      INTEGER INBUFF
      DIMENSION INBUFF(JPACK)
C
C     The GRIBEX routine has a number of different options.
C
      CHARACTER*1 YOPER
C
C     Clear error counter.
      NUMERR = 0
C
C     Set message counter
      NMESSAGE = 0
C
C     Lengths of INBUFF and PSEC4
      ILENB = JPACK
      IPUNP = JPACK * 4

C
      krec=0
      kunit=60 

C     Open data file for reading
      CALL PBOPEN( KUNIT, 'input_gribfile', 'R', ISTATUS)
      WRITE(*,*) 'GRDEMO: After PBOPEN, status      = ', ISTATUS
      IF (ISTATUS .NE. 0) STOP 'GRDEMO: PBOPEN failed'
      WRITE(*,*) ' '
CII>

C
      OPEN(90,file='result.bin',access='direct',form='unformatted',
     /     status='unknown',recl=4*NXMAX*NYMAX,iostat=ios,err=5020)
      if(ios.ne.0) then
         write(*,*) ' hibas a result.bin file megnyitasa '
         stop
      else
         WRITE(*,*) 'GRDEMO: result.bin, status      = ', IOS
      endif
CII<
C
C     This is the beginning of a loop reading one field at a time from
C     the input datafile.
C
   50 CONTINUE
C
      WRITE(*,*) '***********************************************'
      WRITE(*,*) ' '
      CALL PBGRIB( KUNIT, INBUFF, JPACK*JPNBYTE, LENGTH, ISTATUS)
      WRITE(*,*) 'GRDEMO: PBGRIB return status      = ',ISTATUS
C
      IF( ISTATUS.EQ.-1) GOTO 200
      IF( ISTATUS.LT.-1) STOP 'GRDEMO: PBGRIB error reading file'
C
      NMESSAGE = NMESSAGE+1
      WRITE(*,*) 'GRDEMO: Message number            = ', NMESSAGE
      WRITE(*,*) 'GRDEMO: Length of message         = ', LENGTH
C
C     'D' function to unpack entire GRIB message.
      YOPER = 'D'
C
C     Force a return from GRIBEX even if an error occurs.
      ISTATUS = 1
      CALL GRIBEX( ISEC0, ISEC1, ISEC2, ZSEC2, ISEC3, ZSEC3, ISEC4,
     X             ZSEC4, IPUNP, INBUFF, ILENB, IWORD, YOPER, ISTATUS)
C
C     Check return code.
      WRITE(*,*) 'GRDEMO: GRIBEX return code        = ', ISTATUS
      WRITE(*,*) ' '
      WRITE(*,*) '***********************************************'
C
      IF (ISTATUS.EQ.-6) WRITE(*,*) 'GRDEMO: Pseudo-grib data found.'
C
      IF (ISTATUS.GT.0) THEN
        NUMERR = NUMERR + 1
	GO TO 50
      ENDIF
C
C     Print section 0 and 1.
      CALL GRPRS0( ISEC0)
      CALL GRPRS1( ISEC0, ISEC1)
C
C     Print section 2 if present.
      IF (ISEC1(5).EQ.0.OR.ISEC1(5).EQ.64) THEN
        WRITE(*,*) ' '
        WRITE(*,*) 'GRDEMO: No section 2 in GRIB message.'
      ELSE
        CALL GRPRS2( ISEC0, ISEC2, ZSEC2)
      ENDIF
C
C     Print section 3 if present.
      IF (ISEC1(5).EQ.0.OR.ISEC1(5).EQ.128) THEN
        WRITE(*,*) ' '
        WRITE(*,*) 'GRDEMO: No section 3 in GRIB message.'
      ELSE
        CALL GRPRS3( ISEC0, ISEC3, ZSEC3)
      ENDIF
C
C     Print section 4.
      CALL GRPRS4( ISEC0, ISEC4, ZSEC4)
C      
      krec=krec+1
C 
      k=0
      do loop=1,2 
         isec(k+loop) = isec0(loop)
      enddo 
      k=2
      do loop=1,512
         isec(k+loop) = isec1(loop)
      enddo 
      k=514
      do loop=1,512
         isec(k+loop) = isec2(loop)
      enddo
      k=1026 
      do loop=1,2 
         isec(k+loop) = isec3(loop)
      enddo 
      k=1028 
      do loop=1,512 
         isec(k+loop) = isec4(loop)
      enddo


      write(90,rec=krec,iostat=ios) (zsec4(loop),loop=1,NXMAX*NYMAX)
c
      if(ios.ne.0) then
         write(*,*) ' iras hiba, unit=90, iostat= ',ios   
         stop ' iras hiba, unit=90 ' 
      endif
C
C     Loop back for next input field.
      write(80,*)
      GO TO 50
C
C     End-of-file on input.
C
  200 CONTINUE
      WRITE(*,*) 'GRDEMO: End-of-file on input.'
      WRITE(*,*) ' '
      WRITE(*,*) '***********************************************'
      WRITE(*,*) ' '
      WRITE(*,*) 'GRDEMO: Number of messages        = ', NMESSAGE
      WRITE(*,*) 'GRDEMO: Number of decoding errors = ', NUMERR
C

      CLOSE (90) 
C
      STOP
C
C     Error reading input file.
  300 STOP 'GRDEMO: Read error'
C
 5000 stop 'open hiba - header.bin '
 5010 stop 'open hiba - result.asc '
 5020 stop 'open hiba - result.bin ' 
C
      END
EOF

# forditas es futtatas 

LIB1=${LIBRARY_DIR}/libgribex.a

rm -f grdemo.e result.bin result.asc 
f77 -o grdemo.e -C grdemo.f $LIB1 

./grdemo.e >$hdrfile

# output  atnevezese es a nem szukseges fileok torlese 

mv result.bin $binfile

echo
echo Binaris fajl elkeszult:
ls -l $binfile

rm -f a.out input_gribfile grdemo.f grdemo.o

rm -f $hdrfile
#
exit 0
